@@ -35,7 +35,7 @@ Links:
 links = """[github](https://github.com/massgh/pivotpy)             
 [docs](https://massgh.github.io/pivotpy/)"""
 
-__version__ = "1.2.6"
+__version__ = "1.2.7"
 
 __all__ = []
 
@@ -74,9 +74,7 @@ def create_colormap(name='RB',colors=[(0.9,0,0),(0,0,0.9)]):
 
 # color_marices for quick_rgb_lines
 color_matrix = __np.array([[0.5,0,0.5,1],[0.5,0.5,0,1],[0,0.5,0.5,0.2],[1,1,0.2,0]]) # lights up to see colors a little bit
-gray_matrix = __np.array([[1,0,0,0],[0,1,0,1],[0,0,1,0],[0,1,0,0]])
 rbg_matrix= __np.array([[1,0,0],[0,0,1],[0,1,0]]) # Red, Blue, Green
-swap_bg_matrix = rbg_matrix # Alias for backward compatibility
 cmy_matrix = __np.array([[0,0.5,0.5,1],[0.5,0,0.5,1],[0.5,0.5,0,0.2],[1,1,0.2,0]]) # Generates CMYK color palette
 
 
